"""Constants and allowed parameter values specified in the Userlist API."""

PUSH_URL = 'https://push.userlist.com/'



# Date formats
VALID_DATE_FORMATS = ['%Y-%m-%dT%H:%M:%S%z', '%Y-%m-%dT%H:%M:%S']